package jiaowuxitong

import (
	"shylinux.com/x/ice"
	"shylinux.com/x/icebergs/base/ctx"
	"shylinux.com/x/icebergs/base/mdb"
	"shylinux.com/x/icebergs/base/web"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/community/src/gonganxitong"
	"shylinux.com/x/education/src/jiaowuxitong/model"
)

type portal struct {
	gonganxitong.Portal
	city        gonganxitong.City
	user        gonganxitong.User
	userClass   userClass
	class       Class
	school      school
	list        string `name:"list class_uid index uid auto" role:"void"`
	classCreate string `name:"classCreate city_name* school_name* grade*:select name*" role:"void"`
	classRemove string `name:"classRemove class_uid*" role:"void"`
}

func (s portal) Inputs(m *ice.Message, arg ...string) {
	s.class.Inputs(m, arg...)
}
func (s portal) List(m *ice.Message, arg ...string) {
	if m.Option("form") == "table" {
		s.Hash.List(m, arg...).SortInt(mdb.ORDER)
		return
	}
	if len(arg) == 0 {
		m.Cmdy(s.userClass, m.Option(model.USER_UID)).PushAction(s.ClassRemove).Action(s.ClassCreate, s.ScanQRCode)
		kit.If(!m.IsErr() && m.Length() == 0, func() {
			m.EchoInfoButton(m.Trans("Please Create Your Class", "请创建班级"), s.ClassCreate, s.ScanQRCode)
		})
	} else if len(arg) == 2 {
		msg := m.Cmd(s.class, s.class.Select, model.UID, arg[0])
		m.Option(model.CLASS_NAME, msg.Append(model.NAME))
		m.Cmdy(ctx.COMMAND, arg[1]).Push(ctx.ARGS, arg[0])
	} else {
		s.Portal.List(m, arg...)
	}
	m.Display("").DisplayCSS("")
}
func (s portal) ClassCreate(m *ice.Message, arg ...string) {
	defer m.ToastProcess()()
	if s.city.FindOrCreateByName(m, arg...); m.IsErr() {
		return
	}
	if s.school.FindOrCreateByName(m, arg...); m.IsErr() {
		return
	}
	if m.Cmdy(s.class, s.class.Create, arg[2:]).IsErr() {
		return
	}
	args := kit.Simple(m.OptionSimple(model.USER_UID), model.CLASS_UID, m.Result())
	m.Cmdy(s.userClass, s.userClass.Create, args).ProcessRefresh()
}
func (s portal) ClassRemove(m *ice.Message, arg ...string) {
	defer m.ToastProcess()()
	args := m.OptionSimple(model.USER_UID, model.CLASS_UID)
	msg := m.Cmd(s.userClass, s.userClass.Select, args)
	if m.WarnNotFound(msg.Length() == 0, "class") {
		return
	}
	m.Cmdy(s.userClass, s.userClass.Delete, msg.AppendSimple(model.UID))
	m.Cmdy(s.class, s.class.Delete, model.UID, m.Option(model.CLASS_UID))
	m.ProcessRefresh()
}
func (s portal) ScanQRCode(m *ice.Message, arg ...string) {
	defer m.ToastProcess()()
	if m.Option(mdb.TYPE) == mdb.TEXT {
		args := kit.Simple(m.OptionSimple(model.USER_UID), model.CLASS_UID, m.Option(mdb.TEXT))
		m.Cmdy(s.userClass, s.userClass.Create, args, model.ROLE, UserClassVisitor)
	}
	if m.Option(mdb.TYPE) == web.LINK {
		args := m.ParseURL(m.Option(mdb.TEXT))
		if len(args) > 1 && args[1] == m.Prefix("apply") {
			args := kit.Simple(m.OptionSimple(model.USER_UID), model.CLASS_UID, args[0])
			m.Cmdy(s.userClass, s.userClass.Create, args, model.ROLE, UserClassVisitor)
		}
	}
}

func init() { ice.TeamCtxCmd(portal{}) }

func (s portal) Show(m *ice.Message, arg ...string) {
	m.GoSleep("30ms", func() {
		cmd := m.GetCommand()
		m.Cmd(s, s.Create, mdb.NAME, cmd.Help, mdb.ICONS, cmd.Icon, ctx.INDEX, m.PrefixKey())
	})
}
